@@ -2,25 +2,26 @@
 /*
  *  Copyright © 2013 Igalia S.L.
  *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2, or (at your option)
- *  any later version.
+ *  This file is part of Epiphany.
  *
- *  This program is distributed in the hope that it will be useful,
+ *  Epiphany is free software: you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation, either version 3 of the License, or
+ *  (at your option) any later version.
+ *
+ *  Epiphany is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ *  along with Epiphany.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 #include <config.h>
 #include "ephy-embed-form-auth.h"
 
-struct _EphyEmbedFormAuth
-{
+struct _EphyEmbedFormAuth {
   GObject parent_instance;
 
   guint64 page_id;
@@ -62,7 +63,7 @@ EphyEmbedFormAuth *
 ephy_embed_form_auth_new (WebKitWebPage *web_page,
                           WebKitDOMNode *username_node,
                           WebKitDOMNode *password_node,
-                          const char* username)
+                          const char    *username)
 {
   EphyEmbedFormAuth *form_auth;
 
@@ -103,7 +104,7 @@ ephy_embed_form_auth_get_page_id (EphyEmbedFormAuth *form_auth)
   return form_auth->page_id;
 }
 
-const char*
+const char *
 ephy_embed_form_auth_get_username (EphyEmbedFormAuth *form_auth)
 {
   return form_auth->username;
