@@ -22,7 +22,9 @@
 
 #include <glib-object.h>
 #include <gio/gio.h>
+
 #include "ephy-history-types.h"
+#include "ephy-sqlite-connection.h"
 
 G_BEGIN_DECLS
 
@@ -32,7 +34,7 @@ G_DECLARE_FINAL_TYPE (EphyHistoryService, ephy_history_service, EPHY, HISTORY_SE
 
 typedef void   (*EphyHistoryJobCallback)          (EphyHistoryService *service, gboolean success, gpointer result_data, gpointer user_data);
 
-EphyHistoryService *     ephy_history_service_new                     (const char *history_filename, gboolean read_only);
+EphyHistoryService *     ephy_history_service_new                     (const char *history_filename, EphySQLiteConnectionMode mode);
 
 void                     ephy_history_service_add_visit               (EphyHistoryService *self, EphyHistoryPageVisit *visit, GCancellable *cancellable, EphyHistoryJobCallback callback, gpointer user_data);
 void                     ephy_history_service_add_visits              (EphyHistoryService *self, GList *visits, GCancellable *cancellable, EphyHistoryJobCallback callback, gpointer user_data);
